LiquidGlassNavBarAnimationState class
Inputs available to a custom Android navigation indicator animation.
- Annotations
Constructors
-
Creates an immutable indicator animation snapshot.
const
Properties
- center → double
-
Default eased horizontal center for this frame.
final
- dockHeight → double
-
Height of the navigation bar.
final
- dragSpeed → double
-
Absolute drag speed in logical pixels per second.
no setter
- dragVelocity → double
-
Signed horizontal drag velocity in logical pixels per second.
final
- fromCenter → double
-
Horizontal center at the start of a programmatic transition.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- holdProgress → double
-
Hold expansion progress from
0.0to1.0.final - isDragging → bool
-
Whether the user is currently dragging or holding the indicator.
final
- itemWidth → double
-
Width allocated to one navigation item.
final
- restingRect → Rect
-
Resting indicator rectangle at center.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toCenter → double
-
Horizontal center at the end of a programmatic transition.
final
- transitionProgress → double
-
Raw transition progress from
0.0to1.0.final - travelDistance → double
-
Absolute horizontal travel distance for a programmatic transition.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited